// Seleciona o formulário pelo ID
const formulario = document.getElementById("formulario-de-envio-de-mensagens");

// Define a função para validar os dados do formulário
function validarDados() {
  // Seleciona todos os campos de entrada (input e textarea) dentro do formulário
  const campos = formulario.querySelectorAll("input, textarea");
  // Seleciona a área onde as mensagens serão exibidas pelo ID
  const areaDeMensagens = document.getElementById("area-de-mensagens");
  // Inicializa um array para armazenar os campos com erro
  const camposComErro = [];
  // Inicializa um contador para o número de erros encontrados
  let contadorErros = 0;

  // Loop através de cada campo do formulário
  for (let contador = 0; contador < campos.length; contador++) {
    // Verifica se o valor do campo atual está vazio
    if (campos[contador].value == "") {
      // Se estiver vazio, adiciona o campo ao array de campos com erro
      camposComErro[contadorErros] = campos[contador];
      // Incrementa o contador de erros
      contadorErros++;
    }
  }

  // Verifica se há algum campo com erro
  if (camposComErro.length > 0) {
    // Se houver erros, constrói a mensagem de erro HTML
    let erros = `<h2 id='titulo-area-de-mensagens' tabindex='-1'>Existem ${camposComErro.length} erros no formulário</h2>`;
    erros += "<p id='texto-area-de-mensagens'>Corrija os campos a seguir:</p>";
    erros += "<ul>";
    // Loop através dos campos com erro para adicionar cada erro à lista
    for (contadorErros = 0; contadorErros < camposComErro.length; contadorErros++) {
      // Obtém o texto do label associado ao campo com erro
      let labelDoCampo = formulario.querySelector(`label[for="${camposComErro[contadorErros].id}"]`).textContent;
      // Adiciona um item de lista com um link para o campo com erro
      erros += `<li><a href='#${camposComErro[contadorErros].id}'>O campo ${labelDoCampo} não pode ficar vazio</a></li>`;
    }
    erros += "</ul>";
    // Insere a mensagem de erro na área de mensagens
    areaDeMensagens.innerHTML = erros;
  } else {
    // Se não houver erros, constrói a mensagem de confirmação HTML
    let confirmacao = "<h2 id='titulo-area-de-mensagens' tabindex='-1'>Confirmação de envio de dados</h2>";
    confirmacao += "<p id='texto-area-de-mensagens'>Verifique se os dados a seguir foram preenchidos corretamente:</p>";
    confirmacao += "<ul>";
    // Loop através de todos os campos para exibir os dados preenchidos
    for (let contador = 0; contador < campos.length; contador++) {
      // Obtém o texto do label associado ao campo
      let labelDoCampo = formulario.querySelector(`label[for="${campos[contador].id}"]`).textContent;
      // Adiciona um item de lista com o label e o valor do campo
      confirmacao += `<li><a href='#${campos[contador].id}'>${labelDoCampo} ${campos[contador].value}</a></li>`;
    }
    confirmacao += "</ul>";
    // Adiciona um botão para confirmar e enviar os dados
    confirmacao += "<button onclick='enviarMensagem();'>Confirmar dados preenchidos e enviar</button>";
    // Insere a mensagem de confirmação na área de mensagens
    areaDeMensagens.innerHTML = confirmacao;
  }

  // Define o foco no título da área de mensagens
  areaDeMensagens.querySelector("h2").focus();
}

// Define a função para enviar a mensagem
function enviarMensagem() {
  // Exibe um alerta de agradecimento
  alert("Agradecemos pela mensagem!");
  // Envia o formulário
  formulario.submit();
}

// Adiciona um ouvinte de evento para o evento de envio do formulário
formulario.addEventListener("submit", function (event) {
  // Impede o comportamento padrão de envio do formulário
  event.preventDefault();
  // Chama a função para validar os dados do formulário
  validarDados();
});